@@ -11,7 +11,7 @@ use DateTime::Event::Recurrence 0.11;
 use Params::Validate qw(:all);
 use vars qw( $VERSION @ISA );
 @ISA     = qw( Exporter );
-$VERSION = '0.11';
+$VERSION = '0.13';
 
 use constant INFINITY     =>       100 ** 100 ** 100 ;
 use constant NEG_INFINITY => -1 * (100 ** 100 ** 100);
@@ -598,7 +598,16 @@ sub recur {
     if ( exists $args{bymonthday} ||
          exists $args{bymonth} ) 
     {
-        $by_month_day = _yearly_recurrence($dtstart, \%args);
+        my %by = %args;
+        $by{byhour} = $args_backup{byhour} if $args_backup{byhour};
+        $by{byhour} = [ 0 .. 23 ] if $args{freq} eq 'hourly';
+        $by{byminute} = $args_backup{byminute} if $args_backup{byminute};
+        $by{byminute} = [ 0 .. 59 ] if $args{freq} eq 'minutely';
+        $by{bysecond} = $args_backup{bysecond} if $args_backup{bysecond};
+        $by{bysecond} = [ 0 .. 59 ] if $args{freq} eq 'secondly';
+        $by_month_day = _yearly_recurrence($dtstart, \%by);
+        delete $args{bymonthday};
+        delete $args{bymonth};
     }
 
     my $by_week_day;
@@ -606,7 +615,16 @@ sub recur {
     if ( exists $args{byday} ||
          exists $args{byweekno} ) 
     {
-        $by_week_day = _weekly_recurrence($dtstart, \%args);
+        my %by = %args;
+        $by{byhour} = $args_backup{byhour} if $args_backup{byhour};
+        $by{byhour} = [ 0 .. 23 ] if $args{freq} eq 'hourly';
+        $by{byminute} = $args_backup{byminute} if $args_backup{byminute};
+        $by{byminute} = [ 0 .. 59 ] if $args{freq} eq 'minutely';
+        $by{bysecond} = $args_backup{bysecond} if $args_backup{bysecond};
+        $by{bysecond} = [ 0 .. 59 ] if $args{freq} eq 'secondly';
+        $by_week_day = _weekly_recurrence($dtstart, \%by);
+        delete $args{byday};
+        delete $args{byweekno};
     }
 
     my $by_hour;
@@ -673,7 +691,7 @@ DateTime::Event::ICal - Perl DateTime extension for computing rfc2445 recurrence
 
  use DateTime;
  use DateTime::Event::ICal;
- 
+
  my $dt = DateTime->new( year   => 2000,
                          month  => 6,
                          day    => 20,
@@ -711,7 +729,7 @@ C<DateTime::Set> objects for rfc2445 style recurrences.
 
 =item recur
 
-This method returns a C<DateTime::Set> object representing the
+This method returns a L<DateTime::Set> object representing the
 given recurrence.
 
   my $set = DateTime::Event::ICal->recur( %args );
@@ -725,7 +743,7 @@ what all these parameters represent.
 
 =item * dtstart
 
-A DateTime object, which is the start date.
+A L<DateTime> object, which is the start date.
 
 This datetime is not included in the recurrence, unless it satisfies
 the recurrence's rules.
@@ -765,7 +783,7 @@ means a recurrence that occurs every three years.
 =item * wkst
 
 Week start day.  This can be one of: "mo", "tu", "we", "th", "fr",
-"sa", "su".  The default is monday ("mo").
+"sa", "su".  The default is Monday ("mo").
 
 B<Note: this parameter is not yet implemented>
 
@@ -805,7 +823,7 @@ but not zero.  The allowed ranges are -53 to -1, and 1 to 53.
 
 The first week of year is week 1.
 
-The default week start day is monday.
+The default week start day is Monday.
 
 Week -1 is the last week of year.
 
@@ -824,12 +842,14 @@ See RFC 2445, section 4.3.10 for more details.
 
 This can be either a scalar or an array reference of positive and
 negative numbers from -366 to -1, and 1 to 366.  This parameter is
-used in conjuction with one of the other "by..." parameters.
+used in conjunction with one of the other "by..." parameters.
 
 See RFC 2445, section 4.3.10 for more details.
 
 =back
 
+=back
+
 =head1 AUTHOR
 
 Flavio Soibelmann Glock
@@ -854,22 +874,22 @@ with this module.
 
 datetime@perl.org mailing list
 
-DateTime Web page at http://datetime.perl.org/
+L<DateTime Web page|http://datetime.perl.org/>
 
-DateTime
+The L<DateTime> module.
 
-DateTime::Event::Recurrence - simple rule-based recurrences
+L<DateTime::Event::Recurrence> - simple rule-based recurrences.
 
-DateTime::Format::ICal - can parse rfc2445 recurrences
+L<DateTime::Format::ICal> - can parse rfc2445 recurrences.
 
-DateTime::Set - recurrences defined by callback subroutines
+L<DateTime::Set> - recurrences defined by callback subroutines.
 
-DateTime::Event::Cron - recurrences defined by "cron" rules
+L<DateTime::Event::Cron> - recurrences defined by "cron" rules.
 
-DateTime::SpanSet
+L<DateTime::SpanSet>
 
-RFC2445 - Internet Calendaring and Scheduling Core Object
-Specification - http://www.ietf.org/rfc/rfc2445.txt
+L<RFC2445|http://www.ietf.org/rfc/rfc2445.txt> -
+Internet Calendaring and Scheduling Core Object Specification.
 
 =cut
 
